"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateBaseConfig = updateBaseConfig;
exports.getDeployConfig = getDeployConfig;
const ui5_config_1 = require("@sap-ux/ui5-config");
const constants_1 = require("./constants");
/**
 * Updates the base config with the required custom tasks.
 *
 * @param isLib - whether the project is a library
 * @param basePath - the base path
 * @param baseConfig - the base config
 * @param fs - the memfs editor instance
 */
function updateBaseConfig(isLib, basePath, baseConfig, fs) {
    if (isLib) {
        const customTask = {
            name: constants_1.UI5_TASK_FLATTEN_LIB,
            afterTask: 'generateResourcesJson'
        };
        baseConfig.addCustomTasks([customTask]);
        fs.write(basePath, baseConfig.toString());
        baseConfig.removeConfig('builder');
    }
}
/**
 * Returns the deployment config.
 *
 * @param config - the deploy config
 * @param baseConfig - the base config
 * @returns the deploy config
 */
async function getDeployConfig(config, baseConfig) {
    const target = {};
    const comments = [];
    if (config.target.destination !== undefined) {
        target.destination = config.target.destination;
    }
    if (config.target.url !== undefined) {
        target.url = config.target.url;
    }
    if (config.target.client) {
        target.client = config.target.client;
    }
    if (config.target.scp) {
        target.scp = true;
    }
    if (config.target.authenticationType === 'reentranceTicket') {
        target.authenticationType = 'reentranceTicket';
        comments.push({
            path: 'configuration.target.authenticationType',
            comment: ' SAML support for vscode',
            key: 'authenticationType'
        });
    }
    const baseUi5Doc = baseConfig.removeConfig('server');
    const ui5DeployConfig = await ui5_config_1.UI5Config.newInstance(baseUi5Doc.toString());
    ui5DeployConfig.addComment({
        comment: ' yaml-language-server: $schema=https://sap.github.io/ui5-tooling/schema/ui5.yaml.json',
        location: 'beginning'
    });
    ui5DeployConfig.addAbapDeployTask(target, config.app, true, ['/test/'], config.index, comments);
    return ui5DeployConfig;
}
//# sourceMappingURL=config.js.map